pub struct InputLayerNode {
id: NodeId,
input_layer_id: LayerId,
pub input_shreds: Vec<InputShred>,
}Expand description
A node that represents an InputLayer
Fields
id: NodeIdinput_layer_id: LayerIdinput_shreds: Vec<InputShred>The MLEs that are combined to make up this InputLayer.
Implementations
Sourceimpl InputLayerNode
impl InputLayerNode
Sourcepub fn generate_input_layer_description<F: Field>(
&self,
circuit_map: &mut CircuitMap,
) -> Result<InputLayerDescription>
pub fn generate_input_layer_description<F: Field>( &self, circuit_map: &mut CircuitMap, ) -> Result<InputLayerDescription>
From the circuit description map and a starting layer id, create the circuit description of an input layer, adding the input shreds to the circuit map.
Sourceimpl InputLayerNode
impl InputLayerNode
Sourcepub fn new(input_shreds: Option<Vec<InputShred>>) -> Self
pub fn new(input_shreds: Option<Vec<InputShred>>) -> Self
A constructor for an InputLayerNode. Can either be initialized empty or with some InputShreds.
Sourcepub fn add_shred(&mut self, shred: InputShred)
pub fn add_shred(&mut self, shred: InputShred)
A method to add an InputShred to this InputLayerNode
Sourcepub fn input_layer_id(&self) -> LayerId
pub fn input_layer_id(&self) -> LayerId
Get the input layer id of this InputLayerNode.