pub struct InputShred {
id: NodeId,
parent: NodeId,
num_vars: usize,
}Expand description
A struct that represents the description of the data (shape in terms of num_vars)
that will be added to an InputLayerNode.
Fields
id: NodeIdparent: NodeIdnum_vars: usizeImplementations
Sourceimpl InputShred
impl InputShred
Sourcepub fn new(num_vars: usize, source: &InputLayerNode) -> Self
pub fn new(num_vars: usize, source: &InputLayerNode) -> Self
Creates a new InputShred from data
Specifying a source indicates to the layouter that this InputShred should be appended to the source when laying out
Sourcepub fn get_parent(&self) -> NodeId
pub fn get_parent(&self) -> NodeId
Gets the parent NodeId of this InputShred. The InputLayerNode this InputShred will eventually be added to